@@ -21,7 +21,7 @@ import numpy
 
 __author__ = """Tiago Coutinho"""
 __email__ = "coutinhotiago@gmail.com"
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 
 async def send_message_tcp(adu, reader, writer):
@@ -224,8 +224,10 @@ class _Stream:
             self.reader = self.writer = stream
         if hasattr(self.reader, "read_exactly"):
             self.readexactly = self.reader.read_exactly
-        else:
+        elif hasattr(self.reader, "readexactly"):
             self.readexactly = self.reader.readexactly
+        else:
+            self.readexactly = self.reader.read
         if inspect.iscoroutinefunction(self.writer.write):
             self._write_coro = None
 
